@@ -55,7 +55,7 @@ class _BaseBoard:
                 if self._dev.is_open():
                     return device
                 print("\033[1;33m连接失败，设备被占用\033[0m")
-                print('$#&*@{"err_code":101,"err_msg":"串口被占用","device":"mkpiano","extra":{}}@*&#$')
+                # print('$#&*@{"err_code":101,"err_msg":"串口被占用","device":"mkpiano","extra":{}}@*&#$')
             else:
                 print("\033[1;33m连接失败，未检测到设备\033[0m")
                 print('$#&*@{"err_code":101,"err_msg":"未检测到串口","device":"mkpiano","extra":{}}@*&#$')
