@@ -1362,13 +1362,13 @@ class FingertipPiano(_BaseModule):
 
     @property
     def joystick_direction(self):
-        if self.is_joystick_up:
+        if self.is_joystick_up():
             return self.DIRECTION_UP
-        elif self.is_joystick_down:
+        elif self.is_joystick_down():
             return self.DIRECTION_DOWN
-        elif self.is_joystick_left:
+        elif self.is_joystick_left():
             return self.DIRECTION_LEFT
-        elif self.is_joystick_right:
+        elif self.is_joystick_right():
             return self.DIRECTION_RIGHT
         return self.DIRECTION_HOME
 
